@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.008005;
-use version; our $VERSION = version->declare("v1.1.0");
+use version; our $VERSION = version->declare("v2.1.0");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -309,6 +309,13 @@ Commands that are specified by this option will be executed when releasing. If r
 
 If you set this key false, Minilla will not generate 'xt/minilla/minimum_version.t'.
 
+=item requires_external_bin
+
+    requires_external_bin=['tar']
+
+The C<requires_external_bin> command takes the name of a system command
+or program. Build fail if the command does not exist.
+
 =back
 
 =head1 FAQ
@@ -373,6 +380,20 @@ You need to add following line:
 
     module_maker="ModuleBuildTiny"
 
+=item How do I use ExtUtils::MakeMaker with Minilla?
+
+Minilla v2.1.0+ supports EUMM(EXPERIMENTAL).
+
+You need to rewrite minil.toml file.
+You need to add following line:
+
+    module_maker="ExtUtilsMakeMaker"
+
+(There is no profile, yet. Patches welcome.)
+
+I don't suggest to use this module... But you can use this option for maintaining
+primitive modules like Test::TCP.
+
 =back
 
 =head1 AUTHORS
